#!/usr/bin/env python3.2

from pgtoolkit import pgmanager, pgbrowser, pgdiff, toolbase


class SchemaDiffTool(toolbase.SrcDstTool):
    def __init__(self):
        toolbase.SrcDstTool.__init__(self, name='schemadiff', desc='Database schema diff.')
        
        self.parser.add_argument('-s', dest='schema', nargs='*', help='Schema filter')
        self.parser.add_argument('-t', dest='table', nargs='*', help='Table filter')
        self.parser.add_argument('--sql', action='store_true', help='Output is SQL script.')
        
        self.init()

    def main(self):
        srcbrowser = pgbrowser.PgBrowser(self.pgm.get_conn('src'))
        dstbrowser = pgbrowser.PgBrowser(self.pgm.get_conn('dst'))
        
        pgd = pgdiff.PgDiff(srcbrowser, dstbrowser)

        if self.args.schema:
            pgd.filter_schemas(include=self.args.schema)
        
        if self.args.table:
            pgd.filter_tables(include=self.args.table)

        if self.args.sql:
            pgd.print_patch()
        else:
            pgd.print_diff()


tool = SchemaDiffTool()
tool.main()
